@@ -42,6 +42,7 @@ class Partector2Pro(PartectorBluePrint):
             self._write_line("h2001!")  # activates harmonics output
             self._write_line("M0004!")  # activates size dist mode
             self._write_line("X0006!")  # activates verbose mode
+            self._write_line("A0001!")  # activates the antispikes
 
 
 if __name__ == "__main__":
@@ -55,12 +56,12 @@ if __name__ == "__main__":
     assert p2_pro, "No Partector found!"
 
     serial_number = next(iter(p2_pro.keys()))
+    p2 = Partector2Pro(serial_number=serial_number)
 
-    p2 = Partector2Pro(serial_number=serial_number, verb_freq=6)
-    time.sleep(30)
-
-    df = p2.get_data_pandas()
-    print(df)
+    for _ in range(20):
+        time.sleep(3)
+        df = p2.get_data_pandas()
+        print(df)
     # df.to_pickle("p2_pro.pkl")
 
     # for _ in range(10):
